### Widget instantiation timing test results

Computer/OS | Browser | Parsing | Programmatic
--- | --- | --- | ---
100 | 500 | 1000 | 100 | 500 | 1000
MacBook Pro 2.16 OS 10.4 2GB RAM | FF (2.0.0.3) | 303 | 1724 | 3505 | 195 | 1006 | 2266
Safari (2.04) | 192 | 1460 | 4463 | 142 | 895 | 2403
WebKit Nightly (21223) | 110 | 540 | 1096 | 85 | 458 | 940
Dell Precision 2.13 PPro XP SP 2 - 2GB RAM | FF (2.0.0.3) | 282 | 1266 | 2484 | 250 | 890 | 1766
IE7 (7.0.5730.11) | 303 | 2079 | 5172 | 203 | 1140 | 2422

### If you want to play:

1. Run the following tests:
   - http://dojotoolkit.org/~owen/bench/dojo/dijit/bench/test_Button-parse.php?count=100
   - http://dojotoolkit.org/~owen/bench/dojo/dijit/bench/test_Button-programmatic.html?count=100
   Change the "count=" to 100, 500, 1000 for each.
   Restart the browser between each test/count. Run each test 3 times and record the smallest number.
2. Record your tests in the copy of this file in SVN: `dijit/bench/test_Button-results.html` and check it in. Reference ticket #2968.